[Libreoffice-commits] .: 3 commits - basic/source odk/setsdkenv_unix.csh.in solenv/bin

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Mon Aug 27 08:22:59 PDT 2012


 basic/source/basmgr/basmgr.cxx          |   10 ----------
 odk/setsdkenv_unix.csh.in               |    6 +++---
 solenv/bin/modules/installer/epmfile.pm |    4 ++--
 3 files changed, 5 insertions(+), 15 deletions(-)

New commits:
commit 246d26faecb809cf4f013b3fcd1368892100217a
Author: Takeshi Abe <tabe at fixedpoint.jp>
Date:   Mon Aug 27 16:47:08 2012 +0900

    Fix typo LD_LIBARY_PATH
    
    Change-Id: Iff2b85db621eb7b40d8a46a6452b8cae01a91e2e

diff --git a/odk/setsdkenv_unix.csh.in b/odk/setsdkenv_unix.csh.in
index f5a2cdc..34bebd7 100644
--- a/odk/setsdkenv_unix.csh.in
+++ b/odk/setsdkenv_unix.csh.in
@@ -104,7 +104,7 @@ switch (`${OO_SDK_HOME}/config.guess | cut -d"-" -f3,4`)
     set exampleout=SOLARISexample.out
 
     # set LD_LIBRARY_PATH
-    if ( $?LD_LIBARY_PATH == 0) then
+    if ( $?LD_LIBRARY_PATH == 0) then
 	setenv LD_LIBRARY_PATH ${OO_SDK_HOME}/lib:${OO_SDK_OUT}/${exampleout}/lib:${OO_SDK_URE_LIB_DIR}:.
     else
 	setenv LD_LIBRARY_PATH ${OO_SDK_HOME}/lib:${OO_SDK_OUT}/${exampleout}/lib:${OO_SDK_URE_LIB_DIR}:.:${LD_LIBRARY_PATH}
@@ -125,7 +125,7 @@ switch (`${OO_SDK_HOME}/config.guess | cut -d"-" -f3,4`)
     set platform=Linux
 
     # set LD_LIBRARY_PATH
-    if ( $?LD_LIBARY_PATH == 0) then
+    if ( $?LD_LIBRARY_PATH == 0) then
 	setenv LD_LIBRARY_PATH ${OO_SDK_HOME}/lib:${OO_SDK_OUT}/${exampleout}/lib:${OO_SDK_URE_LIB_DIR}:.
     else
 	setenv LD_LIBRARY_PATH ${OO_SDK_HOME}/lib:${OO_SDK_OUT}/${exampleout}/lib:${OO_SDK_URE_LIB_DIR}:.:${LD_LIBRARY_PATH}
@@ -167,7 +167,7 @@ switch (`${OO_SDK_HOME}/config.guess | cut -d"-" -f3,4`)
     set platform=FreeBSD
 
     # set LD_LIBRARY_PATH
-    if ( $?LD_LIBARY_PATH == 0) then
+    if ( $?LD_LIBRARY_PATH == 0) then
 	setenv LD_LIBRARY_PATH ${OO_SDK_HOME}/lib:${OO_SDK_OUT}/${exampleout}/lib:${OO_SDK_URE_LIB_DIR}:.
     else
 	setenv LD_LIBRARY_PATH ${OO_SDK_HOME}/lib:${OO_SDK_OUT}/${exampleout}/lib:${OO_SDK_URE_LIB_DIR}:.:${LD_LIBRARY_PATH}
diff --git a/basic/source/basmgr/basmgr.cxx b/basic/source/basmgr/basmgr.cxx
index c0826c6..733e469 100644
--- a/basic/source/basmgr/basmgr.cxx
+++ b/basic/source/basmgr/basmgr.cxx
@@ -389,7 +389,6 @@ private:
     sal_Bool            bDoLoad;
     sal_Bool            bReference;
     sal_Bool            bPasswordVerified;
-    sal_Bool            bFoundInPath;   // Must not relativated again!
 
     // Lib represents library in new UNO library container
     Reference< XLibraryContainer > mxScriptCont;
@@ -431,9 +430,6 @@ public:
     sal_Bool            IsPasswordVerified() const          { return bPasswordVerified; }
     void            SetPasswordVerified()               { bPasswordVerified = sal_True; }
 
-    sal_Bool            IsFoundInPath() const               { return bFoundInPath; }
-    void            SetFoundInPath( sal_Bool bInPath )      { bFoundInPath = bInPath; }
-
     static BasicLibInfo*    Create( SotStorageStream& rSStream );
 
     Reference< XLibraryContainer > GetLibraryContainer( void )
@@ -534,7 +530,6 @@ BasicLibInfo::BasicLibInfo()
     bReference          = sal_False;
     bPasswordVerified   = sal_False;
     bDoLoad             = sal_False;
-    bFoundInPath        = sal_False;
     mxScriptCont        = NULL;
     aStorageName        = rtl::OUString(szImbedded);
     aRelStorageName     = rtl::OUString(szImbedded);
@@ -895,7 +890,6 @@ void BasicManager::LoadBasicManager( SotStorage& rStorage, const String& rBaseUR
                 if( aPathCFG.SearchFile( aSearchFile, SvtPathOptions::PATH_BASIC ) )
                 {
                     pInfo->SetStorageName( aSearchFile );
-                    pInfo->SetFoundInPath( sal_True );
                 }
             }
         }
commit 6ce769a1ad4fdbd0583cd0f81d7e5a06277338e8
Author: Takeshi Abe <tabe at fixedpoint.jp>
Date:   Mon Aug 27 15:52:30 2012 +0900

    Remove useless member variable
    
    Its usage was died at ac25ae2544969f57b0c3d51a7ee9e3eb047a8915
    
    Change-Id: Ic98a0c36ceb02259b4f3b890f5ea701e56adbb68

diff --git a/basic/source/basmgr/basmgr.cxx b/basic/source/basmgr/basmgr.cxx
index e8ee8bf..c0826c6 100644
--- a/basic/source/basmgr/basmgr.cxx
+++ b/basic/source/basmgr/basmgr.cxx
@@ -116,13 +116,11 @@ struct BasicManagerImpl
     SvMemoryStream*  mpManagerStream;
     SvMemoryStream** mppLibStreams;
     sal_Int32        mnLibStreamCount;
-    sal_Bool         mbError;
 
     BasicManagerImpl( void )
         : mpManagerStream( NULL )
         , mppLibStreams( NULL )
         , mnLibStreamCount( 0 )
-        , mbError( sal_False )
     {}
     ~BasicManagerImpl();
 };
@@ -659,8 +657,6 @@ BasicManager::BasicManager( SotStorage& rStorage, const String& rBaseURL, StarBA
                 *static_cast<SvStream*>(&xBasicStream) >> *( mpImpl->mppLibStreams[nL] );
             }
         }
-        else
-            mpImpl->mbError = sal_True;
     }
     else
     {


More information about the Libreoffice-commits mailing list
diff --git a/solenv/bin/modules/installer/epmfile.pm b/solenv/bin/modules/installer/epmfile.pm
index 7d7da01..817b449 100644
--- a/solenv/bin/modules/installer/epmfile.pm
+++ b/solenv/bin/modules/installer/epmfile.pm
@@ -2401,7 +2401,7 @@ sub create_packages_without_epm
 
         if ( $rpm_failed )
         {
             # Because of the problems with LD_LIBARY_PATH, a direct call of local "rpm" or "rpmbuild" might be successful
             my $rpmprog = "";
             if ( -f "/usr/bin/rpmbuild" ) { $rpmprog = "/usr/bin/rpmbuild"; }
             elsif ( -f "/usr/bin/rpm" ) { $rpmprog = "/usr/bin/rpm"; }
@@ -2420,7 +2420,7 @@ sub create_packages_without_epm
 
                 my $helperreturnvalue = $?; # $? contains the return value of the systemcall
 
-                $infoline = "\nLast try: Using $rpmprog directly (problem with LD_LIBARY_PATH)\n";
+                $infoline = "\nLast try: Using $rpmprog directly (problem with LD_LIBRARY_PATH)\n";
                 push( @installer::globals::logfileinfo, $infoline);
 
                 $infoline = "\nSystemcall: $helpersystemcall\n";
@@ -2401,7 +2401,7 @@ sub create_packages_without_epm
         if ( $rpm_failed )
         {
-            # Because of the problems with LD_LIBARY_PATH, a direct call of local "rpm" or "rpmbuild" might be successful
+            # Because of the problems with LD_LIBRARY_PATH, a direct call of local "rpm" or "rpmbuild" might be successful
             my $rpmprog = "";
             if ( -f "/usr/bin/rpmbuild" ) { $rpmprog = "/usr/bin/rpmbuild"; }
commit 71c1de8f01d10197226a4d8a441089dee879b3cb
Author: Takeshi Abe <tabe at fixedpoint.jp>
Date:   Mon Aug 27 16:34:19 2012 +0900

    Remove unused member variable
    
    Its reference through IsFoundInPath() was dropped at 4c3f33d8d54756d3988c4d4c848712b31027f919
    
    Change-Id: I764808d8a59089a05eccedd297a61aa6e76b01e0
